@@ -23,7 +23,7 @@ use List::Util qw(first);
 use IPC::System::Simple 1.17 qw(runx capturex $EXITVAL);
 use namespace::autoclean 0.16;
 
-our $VERSION = '0.9994';
+our $VERSION = '0.9995';
 
 BEGIN {
     # Force Locale::TextDomain to encode in UTF-8 and to decode all messages.
@@ -126,8 +126,9 @@ has editor => (
     default => sub {
         return
              $ENV{SQITCH_EDITOR}
-          || $ENV{EDITOR}
           || shift->config->get( key => 'core.editor' )
+          || $ENV{VISUAL}
+          || $ENV{EDITOR}
           || ( $^O eq 'MSWin32' ? 'notepad.exe' : 'vi' );
     }
 );
@@ -481,7 +482,7 @@ sub spool {
 
 sub probe {
     my ($ret) = shift->capture(@_);
-    chomp $ret;
+    chomp $ret if $ret;
     return $ret;
 }
 
