@@ -54,6 +54,7 @@ sub run {
         change_id_for_depend
         name_for_change_id
         change_offset_from_id
+        change_id_offset_from_id
         load_change
     );
 
@@ -767,12 +768,13 @@ sub run {
 
         ######################################################################
         # Test deployed_changes(), deployed_changes_since(), load_change, and
-        # change_offset_from_id().
+        # change_offset_from_id(), and change_id_offset_from_id()
         can_ok $engine, qw(
             deployed_changes
             deployed_changes_since
             load_change
             change_offset_from_id
+            change_id_offset_from_id
         );
         my $change_hash = {
             id            => $change->id,
@@ -814,6 +816,11 @@ sub run {
         is_deeply $engine->change_offset_from_id($change2->id, 0), $change2_hash,
             'Should load change with offset 0';
 
+        is_deeply $engine->change_id_offset_from_id($change->id, undef), $change->id,
+            'Should get change ID with no offset';
+        is_deeply $engine->change_id_offset_from_id($change2->id, 0), $change2->id,
+            'Should get change ID with offset 0';
+
         # Now try some offsets.
         is_deeply $engine->change_offset_from_id($change->id, 1), $change2_hash,
             'Should find change with offset 1';
@@ -822,6 +829,13 @@ sub run {
         is_deeply $engine->change_offset_from_id($change->id, 2), undef,
             'Should find undef change with offset 2';
 
+        is_deeply $engine->change_id_offset_from_id($change->id, 1), $change2->id,
+            'Should find change ID with offset 1';
+        is_deeply $engine->change_id_offset_from_id($change2->id, -1), $change->id,
+            'Should find change ID with offset -1';
+        is_deeply $engine->change_id_offset_from_id($change->id, 2), undef,
+            'Should find undef change ID with offset 2';
+
         # Revert change 2.
         ok $engine->log_revert_change($change2), 'Revert "widgets"';
         is_deeply [$engine->deployed_changes], [$change_hash],
